# arpes

  -   - [arpes package](arpes)
        
          -   - [Subpackages](arpes#subpackages)
                
                  - [arpes.analysis package](arpes.analysis)
                  - [arpes.corrections package](arpes.corrections)
                  - [arpes.endstations package](arpes.endstations)
                  - [arpes.fits package](arpes.fits)
                  - [arpes.laue package](arpes.laue)
                  - [arpes.models package](arpes.models)
                  - [arpes.plotting package](arpes.plotting)
                  - [arpes.preparation package](arpes.preparation)
                  - [arpes.utilities package](arpes.utilities)
        
          -   - [Submodules](arpes#submodules)
                
                  - [arpes.bootstrap module](arpes.bootstrap)
                  - [arpes.config module](arpes.config)
                  - [arpes.constants module](arpes.constants)
                  - [arpes.exceptions module](arpes.exceptions)
                  - [arpes.experiment module](arpes.experiment)
                  - [arpes.io module](arpes.io)
                  - [arpes.laser module](arpes.laser)
                  - [arpes.load\_pxt module](arpes.load_pxt)
                  - [arpes.optics module](arpes.optics)
                  - [arpes.pipeline module](arpes.pipeline)
                  - [arpes.pipelines module](arpes.pipelines)
                  - [arpes.provenance module](arpes.provenance)
                  - [arpes.repair module](arpes.repair)
                  - [arpes.simulation module](arpes.simulation)
                  - [arpes.typing module](arpes.typing)
                  - [arpes.widgets module](arpes.widgets)
                  - [arpes.xarray\_extensions
                    module](arpes.xarray_extensions)
                  - [arpes.xarray\_html\_repr
                    module](arpes.xarray_html_repr)
        
          - [Module contents](arpes#module-arpes)
